summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorFriedemann Kleint <Friedemann.Kleint@qt.io>2020-07-08 15:48:46 +0200
committerFriedemann Kleint <Friedemann.Kleint@qt.io>2020-07-13 22:07:46 +0200
commitee0198a0183ec2b0cd9ddc6663110cd8e40320aa (patch)
tree74cb7cc1bbd982200480f66dc1057f71f837675b
parent70f7155fcc20e43f096a029889d8a8117e11f70d (diff)
Move eglconvenience to QtGui
Task-number: QTBUG-83255 Change-Id: I8a008d8906308dd73a0793db5b88d3a1b6fdaf5c Reviewed-by: Qt CI Bot <qt_ci_bot@qt-project.org> Reviewed-by: Tor Arne Vestbø <tor.arne.vestbo@qt.io>
-rw-r--r--src/gui/.prev_CMakeLists.txt36
-rw-r--r--src/gui/CMakeLists.txt46
-rw-r--r--src/gui/opengl/platform/egl/egl.pri32
-rw-r--r--src/gui/opengl/platform/egl/qeglconvenience.cpp (renamed from src/platformsupport/eglconvenience/qeglconvenience.cpp)11
-rw-r--r--src/gui/opengl/platform/egl/qeglconvenience_p.h (renamed from src/platformsupport/eglconvenience/qeglconvenience_p.h)54
-rw-r--r--src/gui/opengl/platform/egl/qeglpbuffer.cpp (renamed from src/platformsupport/eglconvenience/qeglpbuffer.cpp)6
-rw-r--r--src/gui/opengl/platform/egl/qeglpbuffer_p.h (renamed from src/platformsupport/eglconvenience/qeglpbuffer_p.h)12
-rw-r--r--src/gui/opengl/platform/egl/qeglplatformcontext.cpp (renamed from src/platformsupport/eglconvenience/qeglplatformcontext.cpp)8
-rw-r--r--src/gui/opengl/platform/egl/qeglplatformcontext_p.h (renamed from src/platformsupport/eglconvenience/qeglplatformcontext_p.h)16
-rw-r--r--src/gui/opengl/platform/egl/qeglstreamconvenience.cpp (renamed from src/platformsupport/eglconvenience/qeglstreamconvenience.cpp)4
-rw-r--r--src/gui/opengl/platform/egl/qeglstreamconvenience_p.h (renamed from src/platformsupport/eglconvenience/qeglstreamconvenience_p.h)15
-rw-r--r--src/gui/opengl/platform/egl/qt_egl_p.h (renamed from src/platformsupport/eglconvenience/qt_egl_p.h)10
-rw-r--r--src/gui/opengl/platform/egl/qxlibeglintegration.cpp (renamed from src/platformsupport/eglconvenience/qxlibeglintegration.cpp)10
-rw-r--r--src/gui/opengl/platform/egl/qxlibeglintegration_p.h (renamed from src/platformsupport/eglconvenience/qxlibeglintegration_p.h)22
-rw-r--r--src/gui/opengl/platform/platform.pri2
-rw-r--r--src/platformsupport/.prev_CMakeLists.txt3
-rw-r--r--src/platformsupport/CMakeLists.txt3
-rw-r--r--src/platformsupport/eglconvenience/.prev_CMakeLists.txt50
-rw-r--r--src/platformsupport/eglconvenience/CMakeLists.txt53
-rw-r--r--src/platformsupport/eglconvenience/eglconvenience.pro43
-rw-r--r--src/platformsupport/platformsupport.pro2
-rw-r--r--src/plugins/platforms/android/.prev_CMakeLists.txt2
-rw-r--r--src/plugins/platforms/android/CMakeLists.txt4
-rw-r--r--src/plugins/platforms/android/android.pro5
-rw-r--r--src/plugins/platforms/android/qandroidplatformintegration.cpp2
-rw-r--r--src/plugins/platforms/android/qandroidplatformoffscreensurface.cpp2
-rw-r--r--src/plugins/platforms/android/qandroidplatformoffscreensurface.h2
-rw-r--r--src/plugins/platforms/android/qandroidplatformopenglcontext.cpp2
-rw-r--r--src/plugins/platforms/android/qandroidplatformopenglcontext.h2
-rw-r--r--src/plugins/platforms/android/qandroidplatformopenglwindow.cpp2
-rw-r--r--src/plugins/platforms/directfb/.prev_CMakeLists.txt2
-rw-r--r--src/plugins/platforms/directfb/CMakeLists.txt4
-rw-r--r--src/plugins/platforms/directfb/directfb.pro1
-rw-r--r--src/plugins/platforms/directfb/qdirectfb_egl.cpp6
-rw-r--r--src/plugins/platforms/eglfs/.prev_CMakeLists.txt1
-rw-r--r--src/plugins/platforms/eglfs/CMakeLists.txt1
-rw-r--r--src/plugins/platforms/eglfs/api/qeglfscontext.cpp4
-rw-r--r--src/plugins/platforms/eglfs/api/qeglfscontext_p.h2
-rw-r--r--src/plugins/platforms/eglfs/api/qeglfsdeviceintegration.cpp2
-rw-r--r--src/plugins/platforms/eglfs/api/qeglfsglobal_p.h2
-rw-r--r--src/plugins/platforms/eglfs/api/qeglfsintegration.cpp6
-rw-r--r--src/plugins/platforms/eglfs/api/qeglfsoffscreenwindow.cpp2
-rw-r--r--src/plugins/platforms/eglfs/api/qeglfswindow.cpp2
-rw-r--r--src/plugins/platforms/eglfs/deviceintegration/eglfs_emu/qeglfsemulatorintegration.cpp4
-rw-r--r--src/plugins/platforms/eglfs/deviceintegration/eglfs_kms/qeglfskmsgbmwindow.cpp2
-rw-r--r--src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.cpp2
-rw-r--r--src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.h2
-rw-r--r--src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_vsp2/qeglfskmsvsp2integration.cpp2
-rw-r--r--src/plugins/platforms/eglfs/deviceintegration/eglfs_rcar/qeglfsrcarintegration.cpp2
-rw-r--r--src/plugins/platforms/eglfs/eglfsdeviceintegration.pro2
-rw-r--r--src/plugins/platforms/minimalegl/.prev_CMakeLists.txt1
-rw-r--r--src/plugins/platforms/minimalegl/CMakeLists.txt3
-rw-r--r--src/plugins/platforms/minimalegl/minimalegl.pro3
-rw-r--r--src/plugins/platforms/minimalegl/qminimaleglscreen.cpp4
-rw-r--r--src/plugins/platforms/minimalegl/qminimaleglscreen.h2
-rw-r--r--src/plugins/platforms/qnx/qnx.pro3
-rw-r--r--src/plugins/platforms/qnx/qqnxglcontext.h2
-rw-r--r--src/plugins/platforms/wasm/qwasmscreen.cpp4
-rw-r--r--src/plugins/platforms/wasm/wasm.pro3
-rw-r--r--src/plugins/platforms/xcb/gl_integrations/xcb_egl/.prev_CMakeLists.txt27
-rw-r--r--src/plugins/platforms/xcb/gl_integrations/xcb_egl/CMakeLists.txt4
-rw-r--r--src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglcontext.h4
-rw-r--r--src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglinclude.h2
-rw-r--r--src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglintegration.cpp2
-rw-r--r--src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglwindow.cpp4
-rw-r--r--src/plugins/platforms/xcb/gl_integrations/xcb_egl/xcb_egl.pro1
66 files changed, 292 insertions, 289 deletions
diff --git a/src/gui/.prev_CMakeLists.txt b/src/gui/.prev_CMakeLists.txt
index 2aa4c20f5b..ba71e2d6f2 100644
--- a/src/gui/.prev_CMakeLists.txt
+++ b/src/gui/.prev_CMakeLists.txt
@@ -331,6 +331,13 @@ qt_extend_target(Gui CONDITION WIN32
#### Keys ignored in scope 7:.:.:gui.pro:WIN32:
# CMAKE_WINDOWS_BUILD = "True"
+qt_extend_target(Gui CONDITION QT_FEATURE_egl
+ SOURCES
+ opengl/platform/egl/qeglconvenience.cpp opengl/platform/egl/qeglconvenience_p.h
+ opengl/platform/egl/qeglstreamconvenience.cpp opengl/platform/egl/qeglstreamconvenience_p.h
+ opengl/platform/egl/qt_egl_p.h
+)
+
#### Keys ignored in scope 8:.:.:gui.pro:QT_FEATURE_egl:
# CMAKE_EGL_LIBS = "$$cmakeProcessLibs($$QMAKE_LIBS_EGL)"
@@ -687,6 +694,29 @@ qt_extend_target(Gui CONDITION QT_FEATURE_opengl AND QT_FEATURE_xlib AND NOT QT_
X11::X11
)
+qt_extend_target(Gui CONDITION QT_FEATURE_egl AND QT_FEATURE_opengl
+ SOURCES
+ opengl/platform/egl/qeglpbuffer.cpp opengl/platform/egl/qeglpbuffer_p.h
+ opengl/platform/egl/qeglplatformcontext.cpp opengl/platform/egl/qeglplatformcontext_p.h
+)
+
+qt_extend_target(Gui CONDITION QT_FEATURE_egl AND QT_FEATURE_egl_x11
+ SOURCES
+ opengl/platform/egl/qxlibeglintegration.cpp opengl/platform/egl/qxlibeglintegration_p.h
+ LIBRARIES
+ X11::X11
+)
+
+qt_extend_target(Gui CONDITION QT_FEATURE_egl AND NOT QT_FEATURE_egl_x11
+ DEFINES
+ QT_EGL_NO_X11
+)
+
+qt_extend_target(Gui CONDITION QT_FEATURE_dlopen AND QT_FEATURE_egl
+ LIBRARIES
+ ${CMAKE_DL_LIBS}
+)
+
qt_extend_target(Gui CONDITION QT_FEATURE_vulkan
SOURCES
rhi/qrhivulkan.cpp rhi/qrhivulkan_p.h
@@ -700,7 +730,7 @@ qt_extend_target(Gui CONDITION QT_FEATURE_vulkan
Vulkan::Vulkan_nolink
)
-#### Keys ignored in scope 104:.:vulkan:vulkan/vulkan.pri:QT_FEATURE_vkgen:
+#### Keys ignored in scope 110:.:vulkan:vulkan/vulkan.pri:QT_FEATURE_vkgen:
# QMAKE_EXTRA_COMPILERS = "qvkgen_h" "qvkgen_ph" "qvkgen_pimpl"
# QMAKE_QVKGEN_INPUT = "vulkan/vk.xml"
# QMAKE_QVKGEN_LICENSE_HEADER = "$$QT_SOURCE_TREE/header.LGPL"
@@ -716,10 +746,10 @@ qt_extend_target(Gui CONDITION QT_FEATURE_vulkan
# qvkgen_pimpl.input = "QMAKE_QVKGEN_INPUT"
# qvkgen_pimpl.output = "$$OUT_PWD/vulkan/qvulkanfunctions_p.cpp"
-#### Keys ignored in scope 105:.:vulkan:vulkan/vulkan.pri:QT_FEATURE_vulkan:
+#### Keys ignored in scope 111:.:vulkan:vulkan/vulkan.pri:QT_FEATURE_vulkan:
# qvkgen_h.variable_out = "HEADERS"
-#### Keys ignored in scope 106:.:vulkan:vulkan/vulkan.pri:else:
+#### Keys ignored in scope 112:.:vulkan:vulkan/vulkan.pri:else:
# qvkgen_h.CONFIG = "target_predeps" "no_link"
qt_extend_target(Gui CONDITION WASM
diff --git a/src/gui/CMakeLists.txt b/src/gui/CMakeLists.txt
index bca7b4ad7c..7d78ecb282 100644
--- a/src/gui/CMakeLists.txt
+++ b/src/gui/CMakeLists.txt
@@ -410,6 +410,23 @@ qt_extend_target(Gui CONDITION WIN32
#### Keys ignored in scope 7:.:.:gui.pro:WIN32:
# CMAKE_WINDOWS_BUILD = "True"
+# special case begin
+if(QT_FEATURE_egl)
+ qt_find_package(EGL)
+endif()
+# special case end
+
+qt_extend_target(Gui CONDITION QT_FEATURE_egl
+ SOURCES
+ opengl/platform/egl/qeglconvenience.cpp opengl/platform/egl/qeglconvenience_p.h
+ opengl/platform/egl/qeglstreamconvenience.cpp opengl/platform/egl/qeglstreamconvenience_p.h
+ opengl/platform/egl/qt_egl_p.h
+# special case begin
+ LIBRARIES
+ EGL::EGL # special case
+# special case end
+)
+
#### Keys ignored in scope 8:.:.:gui.pro:QT_FEATURE_egl:
# CMAKE_EGL_LIBS = "$$cmakeProcessLibs($$QMAKE_LIBS_EGL)"
@@ -793,6 +810,29 @@ qt_extend_target(Gui CONDITION QT_FEATURE_opengl AND QT_FEATURE_xlib AND NOT QT_
X11::X11
)
+qt_extend_target(Gui CONDITION QT_FEATURE_egl AND QT_FEATURE_opengl
+ SOURCES
+ opengl/platform/egl/qeglpbuffer.cpp opengl/platform/egl/qeglpbuffer_p.h
+ opengl/platform/egl/qeglplatformcontext.cpp opengl/platform/egl/qeglplatformcontext_p.h
+)
+
+qt_extend_target(Gui CONDITION QT_FEATURE_egl AND QT_FEATURE_egl_x11
+ SOURCES
+ opengl/platform/egl/qxlibeglintegration.cpp opengl/platform/egl/qxlibeglintegration_p.h
+ LIBRARIES
+ X11::X11
+)
+
+qt_extend_target(Gui CONDITION QT_FEATURE_egl AND NOT QT_FEATURE_egl_x11
+ DEFINES
+ QT_EGL_NO_X11
+)
+
+qt_extend_target(Gui CONDITION QT_FEATURE_dlopen AND QT_FEATURE_egl
+ LIBRARIES
+ ${CMAKE_DL_LIBS}
+)
+
qt_extend_target(Gui CONDITION QT_FEATURE_vulkan
SOURCES
rhi/qrhivulkan.cpp rhi/qrhivulkan_p.h
@@ -806,7 +846,7 @@ qt_extend_target(Gui CONDITION QT_FEATURE_vulkan
Vulkan::Vulkan_nolink
)
-#### Keys ignored in scope 99:.:vulkan:vulkan/vulkan.pri:QT_FEATURE_vkgen:
+#### Keys ignored in scope 110:.:vulkan:vulkan/vulkan.pri:QT_FEATURE_vkgen:
# special case begin
# We must always generate syncqt-injected header files,
# because we added a custom command earlier for those for framework builds.
@@ -862,10 +902,10 @@ add_custom_command(
# qvkgen_pimpl.input = "QMAKE_QVKGEN_INPUT"
# qvkgen_pimpl.output = "$$OUT_PWD/vulkan/qvulkanfunctions_p.cpp"
-#### Keys ignored in scope 105:.:vulkan:vulkan/vulkan.pri:QT_FEATURE_vulkan:
+#### Keys ignored in scope 111:.:vulkan:vulkan/vulkan.pri:QT_FEATURE_vulkan:
# qvkgen_h.variable_out = "HEADERS"
-#### Keys ignored in scope 106:.:vulkan:vulkan/vulkan.pri:else:
+#### Keys ignored in scope 112:.:vulkan:vulkan/vulkan.pri:else:
# qvkgen_h.CONFIG = "target_predeps" "no_link"
qt_extend_target(Gui CONDITION WASM
diff --git a/src/gui/opengl/platform/egl/egl.pri b/src/gui/opengl/platform/egl/egl.pri
new file mode 100644
index 0000000000..78d3cc2e54
--- /dev/null
+++ b/src/gui/opengl/platform/egl/egl.pri
@@ -0,0 +1,32 @@
+HEADERS += \
+ opengl/platform/egl/qeglconvenience_p.h \
+ opengl/platform/egl/qeglstreamconvenience_p.h \
+ opengl/platform/egl/qt_egl_p.h
+
+SOURCES += \
+ opengl/platform/egl/qeglconvenience.cpp \
+ opengl/platform/egl/qeglstreamconvenience.cpp
+
+qtConfig(opengl) {
+ HEADERS += \
+ opengl/platform/egl/qeglplatformcontext_p.h \
+ opengl/platform/egl/qeglpbuffer_p.h
+
+ SOURCES += \
+ opengl/platform/egl/qeglplatformcontext.cpp \
+ opengl/platform/egl/qeglpbuffer.cpp
+}
+
+qtConfig(egl_x11) {
+ HEADERS += \
+ opengl/platform/egl/qxlibeglintegration_p.h
+ SOURCES += \
+ opengl/platform/egl/qxlibeglintegration.cpp
+ QMAKE_USE_PRIVATE += xlib
+} else {
+ # Avoid X11 header collision, use generic EGL native types
+ DEFINES += QT_EGL_NO_X11
+}
+CONFIG += egl
+
+qtConfig(dlopen): QMAKE_USE_PRIVATE += libdl
diff --git a/src/platformsupport/eglconvenience/qeglconvenience.cpp b/src/gui/opengl/platform/egl/qeglconvenience.cpp
index 5d850f6e20..6076498b3e 100644
--- a/src/platformsupport/eglconvenience/qeglconvenience.cpp
+++ b/src/gui/opengl/platform/egl/qeglconvenience.cpp
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -37,14 +37,15 @@
**
****************************************************************************/
-#include <QByteArray>
-#include <QOpenGLContext>
+
+#include <QtCore/qbytearray.h>
+#include <QtGui/qopenglcontext.h>
#ifdef Q_OS_LINUX
#include <sys/ioctl.h>
#include <linux/fb.h>
#endif
-#include <private/qmath_p.h>
+#include <QtGui/private/qmath_p.h>
#include "qeglconvenience_p.h"
diff --git a/src/platformsupport/eglconvenience/qeglpbuffer.cpp b/src/gui/opengl/platform/egl/qeglpbuffer.cpp
index 15fc089778..55e199a6ad 100644
--- a/src/platformsupport/eglconvenience/qeglpbuffer.cpp
+++ b/src/gui/opengl/platform/egl/qeglpbuffer.cpp
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -37,7 +37,7 @@
**
****************************************************************************/
-#include <QtGui/QOffscreenSurface>
+#include <QtGui/qoffscreensurface.h>
#include "qeglpbuffer_p.h"
#include "qeglconvenience_p.h"
diff --git a/src/platformsupport/eglconvenience/qeglplatformcontext.cpp b/src/gui/opengl/platform/egl/qeglplatformcontext.cpp
index 7f0c347607..561079b48f 100644
--- a/src/platformsupport/eglconvenience/qeglplatformcontext.cpp
+++ b/src/gui/opengl/platform/egl/qeglplatformcontext.cpp
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -41,8 +41,8 @@
#include "qeglconvenience_p.h"
#include "qeglpbuffer_p.h"
#include <qpa/qplatformwindow.h>
-#include <QOpenGLContext>
-#include <QDebug>
+#include <QtGui/qopenglcontext.h>
+#include <QtCore/qdebug.h>
#if defined(Q_OS_ANDROID) && !defined(Q_OS_ANDROID_EMBEDDED)
#include <QtCore/private/qjnihelpers_p.h>
diff --git a/src/platformsupport/eglconvenience/qeglstreamconvenience.cpp b/src/gui/opengl/platform/egl/qeglstreamconvenience.cpp
index 5c336f0553..228cdbb06b 100644
--- a/src/platformsupport/eglconvenience/qeglstreamconvenience.cpp
+++ b/src/gui/opengl/platform/egl/qeglstreamconvenience.cpp
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/platformsupport/eglconvenience/qt_egl_p.h b/src/gui/opengl/platform/egl/qt_egl_p.h
index bf37d07fd8..c33cc8aa21 100644
--- a/src/platformsupport/eglconvenience/qt_egl_p.h
+++ b/src/gui/opengl/platform/egl/qt_egl_p.h
@@ -1,6 +1,6 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtGui module of the Qt Toolkit.
@@ -44,13 +44,17 @@
// W A R N I N G
// -------------
//
-// This file is not part of the Qt API. It exists purely as an
-// implementation detail. This header file may change from version to
+// This file is not part of the Qt API. It exists purely as an
+// implementation detail. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//
+// q(data/text)stream.h must be included before any header file that defines Status
+#include <QtCore/qdatastream.h>
+#include <QtCore/qtextstream.h>
+
#ifdef QT_EGL_NO_X11
# ifndef EGL_NO_X11
# define EGL_NO_X11
diff --git a/src/platformsupport/eglconvenience/qxlibeglintegration.cpp b/src/gui/opengl/platform/egl/qxlibeglintegration.cpp
index ac743e1e38..59f7024c06 100644
--- a/src/platformsupport/eglconvenience/qxlibeglintegration.cpp
+++ b/src/gui/opengl/platform/egl/qxlibeglintegration.cpp
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -37,9 +37,11 @@
**
****************************************************************************/
-#include <QLoggingCategory>
+#include <QtCore/qloggingcategory.h>
#include "qxlibeglintegration_p.h"
+QT_BEGIN_NAMESPACE
+
Q_LOGGING_CATEGORY(lcXlibEglDebug, "qt.egl.xlib.debug")
VisualID QXlibEglIntegration::getCompatibleVisualId(Display *display, EGLDisplay eglDisplay, EGLConfig config)
@@ -160,3 +162,5 @@ VisualID QXlibEglIntegration::getCompatibleVisualId(Display *display, EGLDisplay
qWarning("Unable to find an X11 visual which matches EGL config %d", configId);
return (VisualID)0;
}
+
+QT_END_NAMESPACE
diff --git a/src/gui/opengl/platform/platform.pri b/src/gui/opengl/platform/platform.pri
index 4255f09a4e..193bd9e59b 100644
--- a/src/gui/opengl/platform/platform.pri
+++ b/src/gui/opengl/platform/platform.pri
@@ -1,2 +1,4 @@
qtConfig(xlib):qtConfig(opengl):!qtConfig(opengles2): \
include(unix/unix.pri)
+qtConfig(egl): \
+ include(egl/egl.pri)
diff --git a/src/platformsupport/.prev_CMakeLists.txt b/src/platformsupport/.prev_CMakeLists.txt
index 75ae100805..37775c7a65 100644
--- a/src/platformsupport/.prev_CMakeLists.txt
+++ b/src/platformsupport/.prev_CMakeLists.txt
@@ -6,9 +6,6 @@ add_subdirectory(linuxofono)
if(QT_FEATURE_evdev OR QT_FEATURE_integrityhid OR QT_FEATURE_libinput OR QT_FEATURE_tslib OR QT_FEATURE_xkbcommon)
add_subdirectory(input)
endif()
-if(QT_FEATURE_egl)
- add_subdirectory(eglconvenience)
-endif()
if(QT_FEATURE_kms)
add_subdirectory(kmsconvenience)
endif()
diff --git a/src/platformsupport/CMakeLists.txt b/src/platformsupport/CMakeLists.txt
index 8aca4e5e19..c67671ba3d 100644
--- a/src/platformsupport/CMakeLists.txt
+++ b/src/platformsupport/CMakeLists.txt
@@ -10,9 +10,6 @@ endif()
if(QT_FEATURE_evdev OR QT_FEATURE_integrityhid OR QT_FEATURE_libinput OR QT_FEATURE_tslib OR QT_FEATURE_xkbcommon)
add_subdirectory(input)
endif()
-if(QT_FEATURE_egl)
- add_subdirectory(eglconvenience)
-endif()
if(QT_FEATURE_kms)
add_subdirectory(kmsconvenience)
endif()
diff --git a/src/platformsupport/eglconvenience/.prev_CMakeLists.txt b/src/platformsupport/eglconvenience/.prev_CMakeLists.txt
deleted file mode 100644
index 7b14f544f4..0000000000
--- a/src/platformsupport/eglconvenience/.prev_CMakeLists.txt
+++ /dev/null
@@ -1,50 +0,0 @@
-# Generated from eglconvenience.pro.
-
-#####################################################################
-## EglSupport Module:
-#####################################################################
-
-qt_add_module(EglSupport
- STATIC
- INTERNAL_MODULE
- SOURCES
- qeglconvenience.cpp qeglconvenience_p.h
- qeglstreamconvenience.cpp qeglstreamconvenience_p.h
- qt_egl_p.h
- DEFINES
- QT_NO_CAST_FROM_ASCII
- PUBLIC_LIBRARIES
- Qt::CorePrivate
- Qt::GuiPrivate
- PRECOMPILED_HEADER
- "../../corelib/global/qt_pch.h"
-)
-
-#### Keys ignored in scope 1:.:.:eglconvenience.pro:<TRUE>:
-# MODULE = "egl_support"
-
-## Scopes:
-#####################################################################
-
-qt_extend_target(EglSupport CONDITION QT_FEATURE_opengl
- SOURCES
- qeglpbuffer.cpp qeglpbuffer_p.h
- qeglplatformcontext.cpp qeglplatformcontext_p.h
-)
-
-qt_extend_target(EglSupport CONDITION QT_FEATURE_egl_x11
- SOURCES
- qxlibeglintegration.cpp qxlibeglintegration_p.h
- LIBRARIES
- X11::X11
-)
-
-qt_extend_target(EglSupport CONDITION NOT QT_FEATURE_egl_x11
- DEFINES
- QT_EGL_NO_X11
-)
-
-qt_extend_target(EglSupport CONDITION QT_FEATURE_dlopen
- LIBRARIES
- ${CMAKE_DL_LIBS}
-)
diff --git a/src/platformsupport/eglconvenience/CMakeLists.txt b/src/platformsupport/eglconvenience/CMakeLists.txt
deleted file mode 100644
index 4b709161fd..0000000000
--- a/src/platformsupport/eglconvenience/CMakeLists.txt
+++ /dev/null
@@ -1,53 +0,0 @@
-# Generated from eglconvenience.pro.
-
-#####################################################################
-## EglSupport Module:
-#####################################################################
-
-qt_find_package(EGL) # special case
-
-qt_add_module(EglSupport
- STATIC
- INTERNAL_MODULE
- SOURCES
- qeglconvenience.cpp qeglconvenience_p.h
- qeglstreamconvenience.cpp qeglstreamconvenience_p.h
- qt_egl_p.h
- DEFINES
- QT_NO_CAST_FROM_ASCII
- PUBLIC_LIBRARIES
- Qt::CorePrivate
- Qt::GuiPrivate
- EGL::EGL # special case
- PRECOMPILED_HEADER
- "../../corelib/global/qt_pch.h"
-)
-
-#### Keys ignored in scope 1:.:.:eglconvenience.pro:<TRUE>:
-# MODULE = "egl_support"
-
-## Scopes:
-#####################################################################
-
-qt_extend_target(EglSupport CONDITION QT_FEATURE_opengl
- SOURCES
- qeglpbuffer.cpp qeglpbuffer_p.h
- qeglplatformcontext.cpp qeglplatformcontext_p.h
-)
-
-qt_extend_target(EglSupport CONDITION QT_FEATURE_egl_x11
- SOURCES
- qxlibeglintegration.cpp qxlibeglintegration_p.h
- LIBRARIES
- X11::X11
-)
-
-qt_extend_target(EglSupport CONDITION NOT QT_FEATURE_egl_x11
- DEFINES
- QT_EGL_NO_X11
-)
-
-qt_extend_target(EglSupport CONDITION QT_FEATURE_dlopen
- LIBRARIES
- ${CMAKE_DL_LIBS}
-)
diff --git a/src/platformsupport/eglconvenience/eglconvenience.pro b/src/platformsupport/eglconvenience/eglconvenience.pro
deleted file mode 100644
index e9ee52b53b..0000000000
--- a/src/platformsupport/eglconvenience/eglconvenience.pro
+++ /dev/null
@@ -1,43 +0,0 @@
-TARGET = QtEglSupport
-MODULE = egl_support
-
-QT = core-private gui-private
-CONFIG += static internal_module
-
-DEFINES += QT_NO_CAST_FROM_ASCII
-PRECOMPILED_HEADER = ../../corelib/global/qt_pch.h
-
-HEADERS += \
- qeglconvenience_p.h \
- qeglstreamconvenience_p.h \
- qt_egl_p.h
-
-SOURCES += \
- qeglconvenience.cpp \
- qeglstreamconvenience.cpp
-
-qtConfig(opengl) {
- HEADERS += \
- qeglplatformcontext_p.h \
- qeglpbuffer_p.h
-
- SOURCES += \
- qeglplatformcontext.cpp \
- qeglpbuffer.cpp
-}
-
-qtConfig(egl_x11) {
- HEADERS += \
- qxlibeglintegration_p.h
- SOURCES += \
- qxlibeglintegration.cpp
- QMAKE_USE_PRIVATE += xlib
-} else {
- # Avoid X11 header collision, use generic EGL native types
- DEFINES += QT_EGL_NO_X11
-}
-CONFIG += egl
-
-qtConfig(dlopen): QMAKE_USE_PRIVATE += libdl
-
-load(qt_module)
diff --git a/src/platformsupport/platformsupport.pro b/src/platformsupport/platformsupport.pro
index 06c1a15d4e..0aba04e20e 100644
--- a/src/platformsupport/platformsupport.pro
+++ b/src/platformsupport/platformsupport.pro
@@ -10,8 +10,6 @@ qtConfig(evdev)|qtConfig(tslib)|qtConfig(libinput)|qtConfig(integrityhid)|qtConf
input.depends += devicediscovery
}
-qtConfig(egl): \
- SUBDIRS += eglconvenience
qtConfig(kms): \
SUBDIRS += kmsconvenience
diff --git a/src/plugins/platforms/android/.prev_CMakeLists.txt b/src/plugins/platforms/android/.prev_CMakeLists.txt
index 0a6aa6766e..5b2dada653 100644
--- a/src/plugins/platforms/android/.prev_CMakeLists.txt
+++ b/src/plugins/platforms/android/.prev_CMakeLists.txt
@@ -45,9 +45,9 @@ qt_internal_add_plugin(QAndroidIntegrationPlugin
${CMAKE_CURRENT_SOURCE_DIR}
${QT_SOURCE_TREE}/src/3rdparty/android
PUBLIC_LIBRARIES
+ EGL::EGL
Qt::Core
Qt::CorePrivate
- Qt::EglSupportPrivate
Qt::Gui
Qt::GuiPrivate
android
diff --git a/src/plugins/platforms/android/CMakeLists.txt b/src/plugins/platforms/android/CMakeLists.txt
index d3363de4c7..7fcd42a9bb 100644
--- a/src/plugins/platforms/android/CMakeLists.txt
+++ b/src/plugins/platforms/android/CMakeLists.txt
@@ -3,6 +3,7 @@
#####################################################################
## QAndroidIntegrationPlugin Plugin:
#####################################################################
+qt_find_package(EGL) # special case
qt_internal_add_plugin(QAndroidIntegrationPlugin
OUTPUT_NAME qtforandroid
@@ -46,13 +47,14 @@ qt_internal_add_plugin(QAndroidIntegrationPlugin
${CMAKE_CURRENT_SOURCE_DIR}
${QT_SOURCE_TREE}/src/3rdparty/android
PUBLIC_LIBRARIES
+ EGL::EGL
Qt::Core
Qt::CorePrivate
- Qt::EglSupportPrivate
Qt::Gui
Qt::GuiPrivate
android
jnigraphics
+ EGL::EGL # special case
)
#### Keys ignored in scope 1:.:.:android.pro:<TRUE>:
diff --git a/src/plugins/platforms/android/android.pro b/src/plugins/platforms/android/android.pro
index 8f4a99e0aa..979124473e 100644
--- a/src/plugins/platforms/android/android.pro
+++ b/src/plugins/platforms/android/android.pro
@@ -3,8 +3,7 @@ TARGET = qtforandroid
LIBS += -ljnigraphics -landroid
QT += \
- core-private gui-private \
- egl_support-private
+ core-private gui-private
OTHER_FILES += $$PWD/android.json
@@ -86,6 +85,8 @@ qtConfig(vulkan) {
$$PWD/qandroidplatformvulkanwindow.h
}
+QMAKE_USE += egl
+
PLUGIN_TYPE = platforms
PLUGIN_CLASS_NAME = QAndroidIntegrationPlugin
load(qt_plugin)
diff --git a/src/plugins/platforms/android/qandroidplatformintegration.cpp b/src/plugins/platforms/android/qandroidplatformintegration.cpp
index 3ffbd91c6c..372b32746d 100644
--- a/src/plugins/platforms/android/qandroidplatformintegration.cpp
+++ b/src/plugins/platforms/android/qandroidplatformintegration.cpp
@@ -46,7 +46,7 @@
#include <QOffscreenSurface>
#include <QThread>
-#include <QtEglSupport/private/qeglpbuffer_p.h>
+#include <QtGui/private/qeglpbuffer_p.h>
#include <qpa/qwindowsysteminterface.h>
#include <qpa/qplatformwindow.h>
#include <qpa/qplatformoffscreensurface.h>
diff --git a/src/plugins/platforms/android/qandroidplatformoffscreensurface.cpp b/src/plugins/platforms/android/qandroidplatformoffscreensurface.cpp
index c7d832efb6..f9589cea1a 100644
--- a/src/plugins/platforms/android/qandroidplatformoffscreensurface.cpp
+++ b/src/plugins/platforms/android/qandroidplatformoffscreensurface.cpp
@@ -40,7 +40,7 @@
#include "qandroidplatformoffscreensurface.h"
#include <QtGui/QOffscreenSurface>
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#include <android/native_window.h>
diff --git a/src/plugins/platforms/android/qandroidplatformoffscreensurface.h b/src/plugins/platforms/android/qandroidplatformoffscreensurface.h
index 461f949254..033bc6a03f 100644
--- a/src/plugins/platforms/android/qandroidplatformoffscreensurface.h
+++ b/src/plugins/platforms/android/qandroidplatformoffscreensurface.h
@@ -41,7 +41,7 @@
#define QANDROIDPLATFORMOFFSCREENSURFACETEXTURE_H
#include <qpa/qplatformoffscreensurface.h>
-#include <QtEglSupport/private/qeglplatformcontext_p.h>
+#include <QtGui/private/qeglplatformcontext_p.h>
QT_BEGIN_NAMESPACE
class QOffscreenSurface;
diff --git a/src/plugins/platforms/android/qandroidplatformopenglcontext.cpp b/src/plugins/platforms/android/qandroidplatformopenglcontext.cpp
index ecbd282c91..330330a638 100644
--- a/src/plugins/platforms/android/qandroidplatformopenglcontext.cpp
+++ b/src/plugins/platforms/android/qandroidplatformopenglcontext.cpp
@@ -43,7 +43,7 @@
#include "qandroidplatformintegration.h"
#include "qandroidplatformoffscreensurface.h"
-#include <QtEglSupport/private/qeglpbuffer_p.h>
+#include <QtGui/private/qeglpbuffer_p.h>
#include <QSurface>
#include <QtGui/private/qopenglcontext_p.h>
diff --git a/src/plugins/platforms/android/qandroidplatformopenglcontext.h b/src/plugins/platforms/android/qandroidplatformopenglcontext.h
index 50559e281e..b3dc5b297b 100644
--- a/src/plugins/platforms/android/qandroidplatformopenglcontext.h
+++ b/src/plugins/platforms/android/qandroidplatformopenglcontext.h
@@ -41,7 +41,7 @@
#ifndef QANDROIDPLATFORMOPENGLCONTEXT_H
#define QANDROIDPLATFORMOPENGLCONTEXT_H
-#include <QtEglSupport/private/qeglplatformcontext_p.h>
+#include <QtGui/private/qeglplatformcontext_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/android/qandroidplatformopenglwindow.cpp b/src/plugins/platforms/android/qandroidplatformopenglwindow.cpp
index 3de5d30623..dff7e6ec54 100644
--- a/src/plugins/platforms/android/qandroidplatformopenglwindow.cpp
+++ b/src/plugins/platforms/android/qandroidplatformopenglwindow.cpp
@@ -51,7 +51,7 @@
#include <qpa/qwindowsysteminterface.h>
#include <qpa/qplatformscreen.h>
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#include <android/native_window.h>
#include <android/native_window_jni.h>
diff --git a/src/plugins/platforms/directfb/.prev_CMakeLists.txt b/src/plugins/platforms/directfb/.prev_CMakeLists.txt
index 15e43244f0..c6957d57ec 100644
--- a/src/plugins/platforms/directfb/.prev_CMakeLists.txt
+++ b/src/plugins/platforms/directfb/.prev_CMakeLists.txt
@@ -37,8 +37,6 @@ qt_extend_target(QDirectFbIntegrationPlugin CONDITION QT_CONFIG___contains___dir
qdirectfb_egl.cpp qdirectfb_egl.h
DEFINES
DIRECTFB_GL_EGL
- PUBLIC_LIBRARIES
- Qt::EglSupportPrivate
)
qt_extend_target(QDirectFbIntegrationPlugin CONDITION NOT DIRECTFB_PLATFORM_HOOKS_SOURCES_ISEMPTY
diff --git a/src/plugins/platforms/directfb/CMakeLists.txt b/src/plugins/platforms/directfb/CMakeLists.txt
index be6e08bd8e..5e4a2f2baa 100644
--- a/src/plugins/platforms/directfb/CMakeLists.txt
+++ b/src/plugins/platforms/directfb/CMakeLists.txt
@@ -2,6 +2,7 @@
# begin special case:
qt_find_package(DirectFB)
+qt_find_package(EGL)
# end special case:
#####################################################################
@@ -24,6 +25,7 @@ qt_internal_add_plugin(QDirectFbIntegrationPlugin
qdirectfbwindow.cpp qdirectfbwindow.h
PUBLIC_LIBRARIES
PkgConfig::DirectFB
+ EGL::EGL # special case
Qt::Core
Qt::CorePrivate
Qt::Gui
@@ -41,8 +43,6 @@ qt_extend_target(QDirectFbIntegrationPlugin CONDITION QT_CONFIG___contains___dir
qdirectfb_egl.cpp qdirectfb_egl.h
DEFINES
DIRECTFB_GL_EGL
- PUBLIC_LIBRARIES
- Qt::EglSupportPrivate
)
qt_extend_target(QDirectFbIntegrationPlugin CONDITION NOT DIRECTFB_PLATFORM_HOOKS_SOURCES_ISEMPTY
diff --git a/src/plugins/platforms/directfb/directfb.pro b/src/plugins/platforms/directfb/directfb.pro
index d63d2469ff..df4bbc9e9e 100644
--- a/src/plugins/platforms/directfb/directfb.pro
+++ b/src/plugins/platforms/directfb/directfb.pro
@@ -26,7 +26,6 @@ HEADERS = qdirectfbintegration.h \
# ### port the GL context
contains(QT_CONFIG, directfb_egl) {
- QT += egl_support-private
HEADERS += qdirectfb_egl.h
SOURCES += qdirectfb_egl.cpp
DEFINES += DIRECTFB_GL_EGL
diff --git a/src/plugins/platforms/directfb/qdirectfb_egl.cpp b/src/plugins/platforms/directfb/qdirectfb_egl.cpp
index d3c95f0b65..95e6093fab 100644
--- a/src/plugins/platforms/directfb/qdirectfb_egl.cpp
+++ b/src/plugins/platforms/directfb/qdirectfb_egl.cpp
@@ -47,10 +47,10 @@
#include <qpa/qwindowsysteminterface.h>
#include <QtGui/QScreen>
-#include <QtEglSupport/private/qeglplatformcontext_p.h>
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglplatformcontext_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
-#include <QtEglSupport/private/qt_egl_p.h>
+#include <QtGui/private/qt_egl_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/eglfs/.prev_CMakeLists.txt b/src/plugins/platforms/eglfs/.prev_CMakeLists.txt
index b774fb63f7..871f1b4065 100644
--- a/src/plugins/platforms/eglfs/.prev_CMakeLists.txt
+++ b/src/plugins/platforms/eglfs/.prev_CMakeLists.txt
@@ -22,7 +22,6 @@ qt_add_module(EglFSDeviceIntegration
PUBLIC_LIBRARIES
Qt::CorePrivate
Qt::DeviceDiscoverySupportPrivate
- Qt::EglSupportPrivate
Qt::FbSupportPrivate
Qt::GuiPrivate
Qt::PlatformHeadersPrivate
diff --git a/src/plugins/platforms/eglfs/CMakeLists.txt b/src/plugins/platforms/eglfs/CMakeLists.txt
index 5473e9683f..d6de0cd6a1 100644
--- a/src/plugins/platforms/eglfs/CMakeLists.txt
+++ b/src/plugins/platforms/eglfs/CMakeLists.txt
@@ -23,7 +23,6 @@ qt_add_module(EglFSDeviceIntegration
PUBLIC_LIBRARIES
Qt::CorePrivate
Qt::DeviceDiscoverySupportPrivate
- Qt::EglSupportPrivate
Qt::FbSupportPrivate
Qt::GuiPrivate
Qt::PlatformHeadersPrivate
diff --git a/src/plugins/platforms/eglfs/api/qeglfscontext.cpp b/src/plugins/platforms/eglfs/api/qeglfscontext.cpp
index 2dbf762cf4..5e5c0218da 100644
--- a/src/plugins/platforms/eglfs/api/qeglfscontext.cpp
+++ b/src/plugins/platforms/eglfs/api/qeglfscontext.cpp
@@ -39,8 +39,8 @@
#include "qeglfsglobal_p.h"
#include <QtGui/QSurface>
-#include <QtEglSupport/private/qeglconvenience_p.h>
-#include <QtEglSupport/private/qeglpbuffer_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglpbuffer_p.h>
#include "qeglfscontext_p.h"
#include "qeglfswindow_p.h"
diff --git a/src/plugins/platforms/eglfs/api/qeglfscontext_p.h b/src/plugins/platforms/eglfs/api/qeglfscontext_p.h
index f3b506ac7f..2cea72fb03 100644
--- a/src/plugins/platforms/eglfs/api/qeglfscontext_p.h
+++ b/src/plugins/platforms/eglfs/api/qeglfscontext_p.h
@@ -53,7 +53,7 @@
#include "qeglfsglobal_p.h"
#include "qeglfscursor_p.h"
-#include <QtEglSupport/private/qeglplatformcontext_p.h>
+#include <QtGui/private/qeglplatformcontext_p.h>
#include <QtCore/QVariant>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/eglfs/api/qeglfsdeviceintegration.cpp b/src/plugins/platforms/eglfs/api/qeglfsdeviceintegration.cpp
index b985386a4e..4b5a3c8c70 100644
--- a/src/plugins/platforms/eglfs/api/qeglfsdeviceintegration.cpp
+++ b/src/plugins/platforms/eglfs/api/qeglfsdeviceintegration.cpp
@@ -46,7 +46,7 @@
#include "qeglfsscreen_p.h"
#include "qeglfshooks_p.h"
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#include <QGuiApplication>
#include <private/qguiapplication_p.h>
#include <QScreen>
diff --git a/src/plugins/platforms/eglfs/api/qeglfsglobal_p.h b/src/plugins/platforms/eglfs/api/qeglfsglobal_p.h
index 8d76ff5ee0..88415f911e 100644
--- a/src/plugins/platforms/eglfs/api/qeglfsglobal_p.h
+++ b/src/plugins/platforms/eglfs/api/qeglfsglobal_p.h
@@ -53,7 +53,7 @@
#include <QtCore/qglobal.h>
-#include <QtEglSupport/private/qt_egl_p.h>
+#include <QtGui/private/qt_egl_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/eglfs/api/qeglfsintegration.cpp b/src/plugins/platforms/eglfs/api/qeglfsintegration.cpp
index 62b9c8a7c2..3ce78623fa 100644
--- a/src/plugins/platforms/eglfs/api/qeglfsintegration.cpp
+++ b/src/plugins/platforms/eglfs/api/qeglfsintegration.cpp
@@ -61,10 +61,10 @@
#endif
#include "qeglfsoffscreenwindow_p.h"
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#ifndef QT_NO_OPENGL
-# include <QtEglSupport/private/qeglplatformcontext_p.h>
-# include <QtEglSupport/private/qeglpbuffer_p.h>
+# include <QtGui/private/qeglplatformcontext_p.h>
+# include <QtGui/private/qeglpbuffer_p.h>
#endif
#include <QtGui/private/qgenericunixfontdatabase_p.h>
diff --git a/src/plugins/platforms/eglfs/api/qeglfsoffscreenwindow.cpp b/src/plugins/platforms/eglfs/api/qeglfsoffscreenwindow.cpp
index c96e329816..1a74ac473b 100644
--- a/src/plugins/platforms/eglfs/api/qeglfsoffscreenwindow.cpp
+++ b/src/plugins/platforms/eglfs/api/qeglfsoffscreenwindow.cpp
@@ -40,7 +40,7 @@
#include "qeglfsoffscreenwindow_p.h"
#include "qeglfshooks_p.h"
#include <QtGui/QOffscreenSurface>
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/eglfs/api/qeglfswindow.cpp b/src/plugins/platforms/eglfs/api/qeglfswindow.cpp
index e3b49f79dd..452dba10c7 100644
--- a/src/plugins/platforms/eglfs/api/qeglfswindow.cpp
+++ b/src/plugins/platforms/eglfs/api/qeglfswindow.cpp
@@ -47,7 +47,7 @@
# include <QtGui/QOpenGLContext>
# include <QtOpenGL/private/qopenglcompositorbackingstore_p.h>
#endif
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#include "qeglfswindow_p.h"
#ifndef QT_NO_OPENGL
diff --git a/src/plugins/platforms/eglfs/deviceintegration/eglfs_emu/qeglfsemulatorintegration.cpp b/src/plugins/platforms/eglfs/deviceintegration/eglfs_emu/qeglfsemulatorintegration.cpp
index cb7844aff0..bb840a2e06 100644
--- a/src/plugins/platforms/eglfs/deviceintegration/eglfs_emu/qeglfsemulatorintegration.cpp
+++ b/src/plugins/platforms/eglfs/deviceintegration/eglfs_emu/qeglfsemulatorintegration.cpp
@@ -42,8 +42,8 @@
#include "private/qeglfsintegration_p.h"
#include <private/qguiapplication_p.h>
-#include <QtEglSupport/private/qeglconvenience_p.h>
-#include <QtEglSupport/private/qeglplatformcontext_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglplatformcontext_p.h>
#include <qpa/qwindowsysteminterface.h>
diff --git a/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms/qeglfskmsgbmwindow.cpp b/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms/qeglfskmsgbmwindow.cpp
index a93762e5b4..b5f34ae200 100644
--- a/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms/qeglfskmsgbmwindow.cpp
+++ b/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms/qeglfskmsgbmwindow.cpp
@@ -41,7 +41,7 @@
#include "qeglfskmsgbmintegration.h"
#include "qeglfskmsgbmscreen.h"
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.cpp b/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.cpp
index a480a390d1..794fb4db05 100644
--- a/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.cpp
+++ b/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.cpp
@@ -41,7 +41,7 @@
#include "qeglfskmsegldeviceintegration.h"
#include "qeglfskmsegldevice.h"
#include "qeglfskmsegldevicescreen.h"
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#include "private/qeglfswindow_p.h"
#include "private/qeglfscursor_p.h"
#include <QLoggingCategory>
diff --git a/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.h b/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.h
index 5819d82ebf..8fbbe56412 100644
--- a/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.h
+++ b/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_egldevice/qeglfskmsegldeviceintegration.h
@@ -46,7 +46,7 @@
#include <xf86drm.h>
#include <xf86drmMode.h>
-#include <QtEglSupport/private/qeglstreamconvenience_p.h>
+#include <QtGui/private/qeglstreamconvenience_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_vsp2/qeglfskmsvsp2integration.cpp b/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_vsp2/qeglfskmsvsp2integration.cpp
index 6aeb826fa5..7e8462eb4c 100644
--- a/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_vsp2/qeglfskmsvsp2integration.cpp
+++ b/src/plugins/platforms/eglfs/deviceintegration/eglfs_kms_vsp2/qeglfskmsvsp2integration.cpp
@@ -45,7 +45,7 @@
#include "private/qeglfswindow_p.h"
#include <QtDeviceDiscoverySupport/private/qdevicediscovery_p.h>
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#include <QtCore/QLoggingCategory>
#include <QtCore/QJsonDocument>
#include <QtCore/QJsonObject>
diff --git a/src/plugins/platforms/eglfs/deviceintegration/eglfs_rcar/qeglfsrcarintegration.cpp b/src/plugins/platforms/eglfs/deviceintegration/eglfs_rcar/qeglfsrcarintegration.cpp
index 212ebde05a..9f8dbe4809 100644
--- a/src/plugins/platforms/eglfs/deviceintegration/eglfs_rcar/qeglfsrcarintegration.cpp
+++ b/src/plugins/platforms/eglfs/deviceintegration/eglfs_rcar/qeglfsrcarintegration.cpp
@@ -38,7 +38,7 @@
****************************************************************************/
#include <QDebug>
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#include <EGL/egl.h>
#include "INTEGRITY.h"
#include "qeglfsrcarintegration.h"
diff --git a/src/plugins/platforms/eglfs/eglfsdeviceintegration.pro b/src/plugins/platforms/eglfs/eglfsdeviceintegration.pro
index 85e0d48bc0..2b611f8e69 100644
--- a/src/plugins/platforms/eglfs/eglfsdeviceintegration.pro
+++ b/src/plugins/platforms/eglfs/eglfsdeviceintegration.pro
@@ -12,7 +12,7 @@ QT += \
core-private gui-private \
platformheaders-private \
devicediscovery_support-private \
- fb_support-private egl_support-private
+ fb_support-private
qtHaveModule(input_support-private): \
QT += input_support-private
diff --git a/src/plugins/platforms/minimalegl/.prev_CMakeLists.txt b/src/plugins/platforms/minimalegl/.prev_CMakeLists.txt
index 2b60f9550c..15ce608f04 100644
--- a/src/plugins/platforms/minimalegl/.prev_CMakeLists.txt
+++ b/src/plugins/platforms/minimalegl/.prev_CMakeLists.txt
@@ -17,7 +17,6 @@ qt_internal_add_plugin(QMinimalEglIntegrationPlugin
PUBLIC_LIBRARIES
Qt::Core
Qt::CorePrivate
- Qt::EglSupportPrivate
Qt::Gui
Qt::GuiPrivate
)
diff --git a/src/plugins/platforms/minimalegl/CMakeLists.txt b/src/plugins/platforms/minimalegl/CMakeLists.txt
index c6edc29042..beb4d54257 100644
--- a/src/plugins/platforms/minimalegl/CMakeLists.txt
+++ b/src/plugins/platforms/minimalegl/CMakeLists.txt
@@ -1,4 +1,5 @@
# Generated from minimalegl.pro.
+qt_find_package(EGL) # special case
#####################################################################
## QMinimalEglIntegrationPlugin Plugin:
@@ -18,9 +19,9 @@ qt_internal_add_plugin(QMinimalEglIntegrationPlugin
PUBLIC_LIBRARIES
Qt::Core
Qt::CorePrivate
- Qt::EglSupportPrivate
Qt::Gui
Qt::GuiPrivate
+ EGL::EGL # special case
)
#### Keys ignored in scope 1:.:.:minimalegl.pro:<TRUE>:
diff --git a/src/plugins/platforms/minimalegl/minimalegl.pro b/src/plugins/platforms/minimalegl/minimalegl.pro
index b846e58d7c..3d21a6546b 100644
--- a/src/plugins/platforms/minimalegl/minimalegl.pro
+++ b/src/plugins/platforms/minimalegl/minimalegl.pro
@@ -1,8 +1,7 @@
TARGET = qminimalegl
QT += \
- core-private gui-private \
- egl_support-private
+ core-private gui-private
#DEFINES += QEGL_EXTRA_DEBUG
diff --git a/src/plugins/platforms/minimalegl/qminimaleglscreen.cpp b/src/plugins/platforms/minimalegl/qminimaleglscreen.cpp
index 6e122e28ce..f4cd064f1a 100644
--- a/src/plugins/platforms/minimalegl/qminimaleglscreen.cpp
+++ b/src/plugins/platforms/minimalegl/qminimaleglscreen.cpp
@@ -40,9 +40,9 @@
#include "qminimaleglscreen.h"
#include "qminimaleglwindow.h"
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#ifndef QT_NO_OPENGL
-# include <QtEglSupport/private/qeglplatformcontext_p.h>
+# include <QtGui/private/qeglplatformcontext_p.h>
#endif
#ifdef Q_OPENKODE
diff --git a/src/plugins/platforms/minimalegl/qminimaleglscreen.h b/src/plugins/platforms/minimalegl/qminimaleglscreen.h
index 926936ae32..91b6d366c9 100644
--- a/src/plugins/platforms/minimalegl/qminimaleglscreen.h
+++ b/src/plugins/platforms/minimalegl/qminimaleglscreen.h
@@ -44,7 +44,7 @@
#include <QtCore/QTextStream>
-#include <QtEglSupport/private/qt_egl_p.h>
+#include <QtGui/private/qt_egl_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/qnx/qnx.pro b/src/plugins/platforms/qnx/qnx.pro
index bc7181fa21..1c8ef2cd24 100644
--- a/src/plugins/platforms/qnx/qnx.pro
+++ b/src/plugins/platforms/qnx/qnx.pro
@@ -1,8 +1,7 @@
TARGET = qqnx
QT += \
- core-private gui-private \
- egl_support-private
+ core-private gui-private
# Uncomment this to build with support for IMF once it becomes available in the BBNDK
#CONFIG += qqnx_imf
diff --git a/src/plugins/platforms/qnx/qqnxglcontext.h b/src/plugins/platforms/qnx/qqnxglcontext.h
index 5d807ee9e4..d6d9627d29 100644
--- a/src/plugins/platforms/qnx/qqnxglcontext.h
+++ b/src/plugins/platforms/qnx/qqnxglcontext.h
@@ -46,7 +46,7 @@
#include <QtCore/QSize>
#include <EGL/egl.h>
-#include <QtEglSupport/private/qeglplatformcontext_p.h>
+#include <QtGui/private/qeglplatformcontext_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/wasm/qwasmscreen.cpp b/src/plugins/platforms/wasm/qwasmscreen.cpp
index a2bcd4fcb4..0f1fd886d0 100644
--- a/src/plugins/platforms/wasm/qwasmscreen.cpp
+++ b/src/plugins/platforms/wasm/qwasmscreen.cpp
@@ -37,9 +37,9 @@
#include <emscripten/bind.h>
#include <emscripten/val.h>
-#include <QtEglSupport/private/qeglconvenience_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
#ifndef QT_NO_OPENGL
-# include <QtEglSupport/private/qeglplatformcontext_p.h>
+# include <QtGui/private/qeglplatformcontext_p.h>
#endif
#include <qpa/qwindowsysteminterface.h>
#include <QtCore/qcoreapplication.h>
diff --git a/src/plugins/platforms/wasm/wasm.pro b/src/plugins/platforms/wasm/wasm.pro
index e5feaaf944..d6f75969d5 100644
--- a/src/plugins/platforms/wasm/wasm.pro
+++ b/src/plugins/platforms/wasm/wasm.pro
@@ -1,8 +1,7 @@
TARGET = qwasm
CONFIG += static plugin
QT += \
- core-private gui-private \
- egl_support-private
+ core-private gui-private
qtConfig(opengl): QT += opengl-private
diff --git a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/.prev_CMakeLists.txt b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/.prev_CMakeLists.txt
new file mode 100644
index 0000000000..3c792595d0
--- /dev/null
+++ b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/.prev_CMakeLists.txt
@@ -0,0 +1,27 @@
+# Generated from xcb_egl.pro.
+
+#####################################################################
+## QXcbEglIntegrationPlugin Plugin:
+#####################################################################
+
+qt_internal_add_plugin(QXcbEglIntegrationPlugin
+ OUTPUT_NAME qxcb-egl-integration
+ TYPE xcbglintegrations
+ SOURCES
+ qxcbeglcontext.h
+ qxcbeglintegration.cpp qxcbeglintegration.h
+ qxcbeglmain.cpp
+ qxcbeglnativeinterfacehandler.cpp qxcbeglnativeinterfacehandler.h
+ qxcbeglwindow.cpp qxcbeglwindow.h
+ DEFINES
+ QT_NO_FOREACH
+ INCLUDE_DIRECTORIES
+ ..
+ ../..
+ PUBLIC_LIBRARIES
+ Qt::Core
+ Qt::CorePrivate
+ Qt::Gui
+ Qt::GuiPrivate
+ Qt::XcbQpaPrivate
+)
diff --git a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/CMakeLists.txt b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/CMakeLists.txt
index bfe5f25eaf..a1cecaf719 100644
--- a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/CMakeLists.txt
+++ b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/CMakeLists.txt
@@ -4,6 +4,8 @@
## QXcbEglIntegrationPlugin Plugin:
#####################################################################
+qt_find_package(EGL) # special case
+
qt_internal_add_plugin(QXcbEglIntegrationPlugin
OUTPUT_NAME qxcb-egl-integration
TYPE xcbglintegrations
@@ -21,8 +23,8 @@ qt_internal_add_plugin(QXcbEglIntegrationPlugin
PUBLIC_LIBRARIES
Qt::Core
Qt::CorePrivate
- Qt::EglSupportPrivate
Qt::Gui
Qt::GuiPrivate
Qt::XcbQpaPrivate
+ EGL::EGL # special case
)
diff --git a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglcontext.h b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglcontext.h
index a2d677a82f..3c3e497e66 100644
--- a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglcontext.h
+++ b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglcontext.h
@@ -41,8 +41,8 @@
#define QXCBEGLCONTEXT_H
#include "qxcbeglwindow.h"
-#include <QtEglSupport/private/qeglplatformcontext_p.h>
-#include <QtEglSupport/private/qeglpbuffer_p.h>
+#include <QtGui/private/qeglplatformcontext_p.h>
+#include <QtGui/private/qeglpbuffer_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglinclude.h b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglinclude.h
index a5a47dd0bb..e9c3a0c913 100644
--- a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglinclude.h
+++ b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglinclude.h
@@ -46,7 +46,7 @@
#include <QtGui/private/qcssparser_p.h>
#include <QtGui/private/qtextengine_p.h>
-#include <QtEglSupport/private/qt_egl_p.h>
+#include <QtGui/private/qt_egl_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglintegration.cpp b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglintegration.cpp
index 5f6c7bf903..36b971f52d 100644
--- a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglintegration.cpp
+++ b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglintegration.cpp
@@ -42,7 +42,7 @@
#include "qxcbeglcontext.h"
#include <QtGui/QOffscreenSurface>
-#include <QtEglSupport/private/qeglstreamconvenience_p.h>
+#include <QtGui/private/qeglstreamconvenience_p.h>
#include "qxcbeglnativeinterfacehandler.h"
diff --git a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglwindow.cpp b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglwindow.cpp
index 30e3381993..881d85e5f7 100644
--- a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglwindow.cpp
+++ b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/qxcbeglwindow.cpp
@@ -41,8 +41,8 @@
#include "qxcbeglintegration.h"
-#include <QtEglSupport/private/qeglconvenience_p.h>
-#include <QtEglSupport/private/qxlibeglintegration_p.h>
+#include <QtGui/private/qeglconvenience_p.h>
+#include <QtGui/private/qxlibeglintegration_p.h>
QT_BEGIN_NAMESPACE
diff --git a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/xcb_egl.pro b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/xcb_egl.pro
index a39e00ec59..fe10ca4acd 100644
--- a/src/plugins/platforms/xcb/gl_integrations/xcb_egl/xcb_egl.pro
+++ b/src/plugins/platforms/xcb/gl_integrations/xcb_egl/xcb_egl.pro
@@ -1,7 +1,6 @@
TARGET = qxcb-egl-integration
include(../gl_integrations_plugin_base.pri)
-QT += egl_support-private
CONFIG += egl
diff --git a/src/platformsupport/eglconvenience/qeglconvenience_p.h b/src/gui/opengl/platform/egl/qeglconvenience_p.h
index cdc14be45f..7675d1316a 100644
--- a/src/platformsupport/eglconvenience/qeglconvenience_p.h
+++ b/src/gui/opengl/platform/egl/qeglconvenience_p.h
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -44,35 +44,51 @@
// W A R N I N G
// -------------
//
-// This file is not part of the Qt API. It exists purely as an
-// implementation detail. This header file may change from version to
+// This file is not part of the Qt API. It exists purely as an
+// implementation detail. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//
-#include <QtGui/QSurfaceFormat>
-#include <QtCore/QList>
-#include <QtCore/QSizeF>
-#include <QtEglSupport/private/qt_egl_p.h>
+#include <QtGui/qsurfaceformat.h>
+#include <QtCore/qlist.h>
+#include <QtCore/qsize.h>
+
+#include <QtGui/private/qt_egl_p.h>
+
QT_BEGIN_NAMESPACE
-QList<EGLint> q_createConfigAttributesFromFormat(const QSurfaceFormat &format);
-bool q_reduceConfigAttributes(QList<EGLint> *configAttributes);
-EGLConfig q_configFromGLFormat(EGLDisplay display, const QSurfaceFormat &format, bool highestPixelFormat = false, int surfaceType = EGL_WINDOW_BIT);
-QSurfaceFormat q_glFormatFromConfig(EGLDisplay display, const EGLConfig config, const QSurfaceFormat &referenceFormat = QSurfaceFormat());
-bool q_hasEglExtension(EGLDisplay display,const char* extensionName);
-void q_printEglConfig(EGLDisplay display, EGLConfig config);
+Q_GUI_EXPORT QList<EGLint> q_createConfigAttributesFromFormat(const QSurfaceFormat &format);
+
+Q_GUI_EXPORT bool q_reduceConfigAttributes(QList<EGLint> *configAttributes);
+
+Q_GUI_EXPORT EGLConfig q_configFromGLFormat(EGLDisplay display,
+ const QSurfaceFormat &format,
+ bool highestPixelFormat = false,
+ int surfaceType = EGL_WINDOW_BIT);
+
+Q_GUI_EXPORT QSurfaceFormat q_glFormatFromConfig(EGLDisplay display, const EGLConfig config,
+ const QSurfaceFormat &referenceFormat = {});
+
+Q_GUI_EXPORT bool q_hasEglExtension(EGLDisplay display,const char* extensionName);
+
+Q_GUI_EXPORT void q_printEglConfig(EGLDisplay display, EGLConfig config);
#ifdef Q_OS_UNIX
-QSizeF q_physicalScreenSizeFromFb(int framebufferDevice, const QSize &screenSize = QSize());
-QSize q_screenSizeFromFb(int framebufferDevice);
-int q_screenDepthFromFb(int framebufferDevice);
-qreal q_refreshRateFromFb(int framebufferDevice);
+Q_GUI_EXPORT QSizeF q_physicalScreenSizeFromFb(int framebufferDevice,
+ const QSize &screenSize = {});
+
+Q_GUI_EXPORT QSize q_screenSizeFromFb(int framebufferDevice);
+
+Q_GUI_EXPORT int q_screenDepthFromFb(int framebufferDevice);
+
+Q_GUI_EXPORT qreal q_refreshRateFromFb(int framebufferDevice);
+
#endif
-class QEglConfigChooser
+class Q_GUI_EXPORT QEglConfigChooser
{
public:
QEglConfigChooser(EGLDisplay display);
@@ -1,9 +1,9 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
diff --git a/src/platformsupport/eglconvenience/qeglpbuffer_p.h b/src/gui/opengl/platform/egl/qeglpbuffer_p.h
index a137d0d328..370c430f38 100644
--- a/src/platformsupport/eglconvenience/qeglpbuffer_p.h
+++ b/src/gui/opengl/platform/egl/qeglpbuffer_p.h
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -44,19 +44,19 @@
// W A R N I N G
// -------------
//
-// This file is not part of the Qt API. It exists purely as an
-// implementation detail. This header file may change from version to
+// This file is not part of the Qt API. It exists purely as an
+// implementation detail. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//
#include <qpa/qplatformoffscreensurface.h>
-#include <QtEglSupport/private/qeglplatformcontext_p.h>
+#include <QtGui/private/qeglplatformcontext_p.h>
QT_BEGIN_NAMESPACE
-class QEGLPbuffer : public QPlatformOffscreenSurface
+class Q_GUI_EXPORT QEGLPbuffer : public QPlatformOffscreenSurface
{
public:
QEGLPbuffer(EGLDisplay display, const QSurfaceFormat &format, QOffscreenSurface *offscreenSurface,
@@ -1,9 +1,9 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
diff --git a/src/platformsupport/eglconvenience/qeglplatformcontext_p.h b/src/gui/opengl/platform/egl/qeglplatformcontext_p.h
index 4a0be36b61..899f4b5c9f 100644
--- a/src/platformsupport/eglconvenience/qeglplatformcontext_p.h
+++ b/src/gui/opengl/platform/egl/qeglplatformcontext_p.h
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -44,8 +44,8 @@
// W A R N I N G
// -------------
//
-// This file is not part of the Qt API. It exists purely as an
-// implementation detail. This header file may change from version to
+// This file is not part of the Qt API. It exists purely as an
+// implementation detail. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
@@ -54,14 +54,14 @@
#include <QtCore/qtextstream.h>
#include <qpa/qplatformwindow.h>
#include <qpa/qplatformopenglcontext.h>
-#include <QtCore/QVariant>
-#include <QtEglSupport/private/qt_egl_p.h>
+#include <QtCore/qvariant.h>
+#include <QtGui/private/qt_egl_p.h>
#include <QtGui/private/qopenglcontext_p.h>
QT_BEGIN_NAMESPACE
-class QEGLPlatformContext : public QPlatformOpenGLContext,
- public QPlatformInterface::QEGLContext
+class Q_GUI_EXPORT QEGLPlatformContext : public QPlatformOpenGLContext,
+ public QPlatformInterface::QEGLContext
{
public:
enum Flag {
@@ -1,9 +1,9 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
diff --git a/src/platformsupport/eglconvenience/qeglstreamconvenience_p.h b/src/gui/opengl/platform/egl/qeglstreamconvenience_p.h
index c3d3070210..22e124b279 100644
--- a/src/platformsupport/eglconvenience/qeglstreamconvenience_p.h
+++ b/src/gui/opengl/platform/egl/qeglstreamconvenience_p.h
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -44,15 +44,16 @@
// W A R N I N G
// -------------
//
-// This file is not part of the Qt API. It exists purely as an
-// implementation detail. This header file may change from version to
+// This file is not part of the Qt API. It exists purely as an
+// implementation detail. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//
-#include <qglobal.h>
-#include <QtEglSupport/private/qt_egl_p.h>
+#include <QtGui/qtguiglobal.h>
+
+#include <QtGui/private/qt_egl_p.h>
// This provides runtime EGLDevice/Output/Stream support even when eglext.h in
// the sysroot is not up-to-date.
@@ -158,7 +159,7 @@ typedef EGLBoolean (EGLAPIENTRYP PFNEGLSTREAMCONSUMERRELEASEATTRIBNVPROC) (EGLDi
QT_BEGIN_NAMESPACE
-class QEGLStreamConvenience
+class Q_GUI_EXPORT QEGLStreamConvenience
{
public:
QEGLStreamConvenience();
@@ -1,9 +1,9 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
diff --git a/src/platformsupport/eglconvenience/qxlibeglintegration_p.h b/src/gui/opengl/platform/egl/qxlibeglintegration_p.h
index 899b217146..2c4e0b5080 100644
--- a/src/platformsupport/eglconvenience/qxlibeglintegration_p.h
+++ b/src/gui/opengl/platform/egl/qxlibeglintegration_p.h
@@ -1,9 +1,9 @@
/****************************************************************************
**
-** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2020 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -37,29 +37,33 @@
**
****************************************************************************/
-#ifndef QTESTLITEEGLINTEGRATION_H
-#define QTESTLITEEGLINTEGRATION_H
+#ifndef QXLIBEGLINTEGRATION_H
+#define QXLIBEGLINTEGRATION_H
//
// W A R N I N G
// -------------
//
-// This file is not part of the Qt API. It exists purely as an
-// implementation detail. This header file may change from version to
+// This file is not part of the Qt API. It exists purely as an
+// implementation detail. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//
-#include "qeglconvenience_p.h"
+#include <QtGui/private/qeglconvenience_p.h>
#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
-class QXlibEglIntegration
+QT_BEGIN_NAMESPACE
+
+class Q_GUI_EXPORT QXlibEglIntegration
{
public:
static VisualID getCompatibleVisualId(Display *display, EGLDisplay eglDisplay, EGLConfig config);
};
-#endif // QTESTLITEEGLINTEGRATION_H
+QT_END_NAMESPACE
+
+#endif // QXLIBEGLINTEGRATION_H
@@ -1,9 +1,9 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the plugins of the Qt Toolkit.
+** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$